@@ -126,24 +126,27 @@ def clustering_caha_score_by_ncomp(mat, clustermodel, ncompmin=2, ncompmax=20):
     return metrics.calinski_harabasz_score(mat, clustermodel)
 
 
-def censor_data(mat, p=0.0, inplace=True, randomgen=None):
+def censor_data(mat, p=0.0, censored_indices=[], inplace=True, randomgen=None):
     """
 
     """
     assert (0.0 <= p < 1.0)
-    if p == 0.0:
+    if p == 0.0 and len(censored_indices) == 0:
         return mat.copy() if not inplace else None
     else:
         if randomgen is None:
             randomgen = np.random.default_rng()
         nr = len(mat.index)
-        nans = int(abs(p) * nr)
         matc = mat if inplace else mat.copy()
-
-        for icol, _ in enumerate(matc.columns):
-            # censored_idx = np.random.Generator.choice(range(nr), nans, replace=False)
-            censored_idx = randomgen.choice(range(nr), nans, replace=False)
-            matc.iloc[censored_idx, icol] = np.nan
+        if len(censored_indices) > 0:
+            for idx in censored_indices:
+                matc.iloc[idx[0], idx[1]] = np.nan
+        else:
+            nans = int(abs(p) * nr)
+            for icol, _ in enumerate(matc.columns):
+                # censored_idx = np.random.Generator.choice(range(nr), nans, replace=False)
+                censored_idx = randomgen.choice(range(nr), nans, replace=False)
+                matc.iloc[censored_idx, icol] = np.nan
 
         return None if inplace else matc
 
@@ -714,11 +717,15 @@ def generate_vectors_bouquet(vpivot, bouquet_size: int, min_corr: float,
     epsilon = (1 - min_corr)**0.5
     n2v = norm_n2(vpivot)
     for icol in range(bouquet_size):
-        w = generate_orthogonal_vector(vpivot)
-        n2w = norm_n2(w)
-        rescaled_w = epsilon * n2v / n2w * pd.DataFrame(w)
-        vals = vpivot.values + rescaled_w.values
-        df_bouquet.loc[:, col_shift+icol] = vals
+        if nr > 1:
+            w = generate_orthogonal_vector(vpivot)
+            n2w = norm_n2(w)
+            rescaled_w = epsilon * n2v / n2w * pd.DataFrame(w)
+            vals = vpivot.values + rescaled_w.values
+            df_bouquet.loc[:, col_shift+icol] = vals
+        else:
+            vals = vpivot.values + epsilon * np.random.uniform(0, 1.0)
+            df_bouquet.loc[:, col_shift+icol] = vals
     if positive:
         minval = np.min(np.min(df_bouquet))
         if minval < 0:
@@ -728,7 +735,7 @@ def generate_vectors_bouquet(vpivot, bouquet_size: int, min_corr: float,
 
 def generate_clusters_centroids(ndim: int, max_corr: float) -> pd.DataFrame:
 
-    assert (ndim > 1)
+    assert (ndim >= 1)
     assert (0 <= max_corr < 1)
     a = ndim / 4.0 * (1 - max_corr / 3)
     b = 1 - max_corr
@@ -746,7 +753,7 @@ def generate_clusters_centroids(ndim: int, max_corr: float) -> pd.DataFrame:
 
 def generate_integer_partition(ntot: int, nbpart: int, nmin: int = 1):
 
-    assert(ntot >= nbpart*nmin)
+    # assert(ntot >= nbpart*nmin)
     rng = np.random.default_rng()
     cuts = np.sort(rng.choice(ntot, nbpart, replace=False))
     res = []
