@@ -242,7 +242,7 @@ if __name__ == "__main__":
         # eps = np.random.uniform(low=0.0, high=0.25)
         eps = 0.10
         gen_M, _, _, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size, n_obs=w_size,
-                                                         min_intra_corr=min_corr, max_inter_corr=max_corr, epsilon=eps,
+                                                         h_icorr_min=min_corr, h_icorr_max=max_corr, epsilon=eps,
                                                          random_norms=rnd_norms)
         imp_nmf_proxy = imp.Imputer(method="nmf.proxy",
                                     params={"ncomp": 3,
@@ -298,8 +298,8 @@ if __name__ == "__main__":
                                [[0, 0]],
                                [[0, 0], [1, 2]]]
         gen_m, gen_w, gen_h, gen_noise = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size,
-                                                                         n_obs=w_size, min_intra_corr=min_corr,
-                                                                         max_inter_corr=max_corr, epsilon=eps,
+                                                                         n_obs=w_size, h_icorr_min=min_corr,
+                                                                         h_icorr_max=max_corr, epsilon=eps,
                                                                          random_norms=random_norms,
                                                                          wclust_factor=wclust_factor)
         for censor_indices in censor_indices_list:
@@ -356,8 +356,8 @@ if __name__ == "__main__":
                 wh_name = f"M_nc{nb_clusters}_corrmin{round(min_corr, 2)}_" \
                           f"corrmax{round(max_corr, 2)}_noise{round(eps, 2)}_{rnstr}_mis{censor_rate}.csv"
                 gen_M, gen_w, gen_h, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size,
-                                                                         n_obs=w_size, min_intra_corr=min_corr,
-                                                                         max_inter_corr=max_corr, epsilon=eps,
+                                                                         n_obs=w_size, h_icorr_min=min_corr,
+                                                                         h_icorr_max=max_corr, epsilon=eps,
                                                                          random_norms=random_norms)
 
             utl.censor_data(mat=gen_M, p=censor_rate, inplace=True)
